==> img0ch-2.1.17.tar.bz2: img0ch/_template/zeromin2/meta_load_thread_end.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_header&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ヘッダー(ローカルルール)編集</a><br />
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_meta&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">メタデータ編集</a><br />
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_footer&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">フッター編集</a><br />
  </div>
</div>

<div id="main">

<form id="metaThreadFooterContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_header&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">メタデータ</a>
  &gt;
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_thread_end&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッドフッター(1000.txt)編集</a><br />
</div>

<h1>スレッドフッター(1000.txt)編集</h1>

<?cs if:Code0 ?>
<?cs if:Done_meta_save_thread_end ?><div class="noticeSuccess" id="notify"><p>スレッドフッター(1000.txt)を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>時刻欄の形式が正しくありません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/respreview.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
var formArea;
jQuery(function(){
new Zeromin2.ResPreview({
    "content":     "<div class='footer' id='preview'></div>",
    "date":        "<?cs var:html_escape(item.date) ?>",
    "formID":      "metaThreadFooterContainerForm",
    "isTypeTheme": <?cs if:IsTypeTheme ?>true<?cs else ?>false<?cs /if ?>,
    "staticURI":   "<?cs var:html_escape(StaticURI) ?>",
    "text":        "<?cs var:text ?>",
    "typeTheme":   "<?cs var:html_escape(BBS_TYPE_THEME) ?>" });
});
//]]>
</script>

<p>
スレッドフッター(1000.txt)を編集します。<br />
プレビューを表示させるにはiframeとJavaScriptを有効にする必要があります。
</p>

<p>
<div id="previewFrame" class="hide"><iframe></iframe></div>
<input type="submit" value="1000.txtの更新を行う" /><br />
<label for="FROM" title="FROM">名前欄</label>
<input type="text" size="40" id="FROM" name="FROM" title="FROM" value="<?cs var:html_escape(Name) ?>" /><br />
<label for="mail">メール欄</label>
<input type="text" size="40" id="mail" name="mail" title="mail" value="<?cs var:html_escape(Mail) ?>" /><br />
<label for="date">時刻</label>
<input type="text" size="40" id="date" name="date" title="title" value="<?cs var:html_escape(Date) ?>" /><br />
<textarea name="MESSAGE" cols="50" rows="10">
<?cs var:html_escape(Message) ?>
</textarea><br />
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="meta" />
<input type="hidden" name="method" value="save_thread_end" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_thread_end" />
<input type="hidden" name="NG" value="load_thread_end" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/meta_load_thread_end.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/meta_side_menu.cs" ?>

<div id="main">

<form id="metaThreadFooterContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_header&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">メタデータ</a>
  &gt;
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=meta&amp;method=load_thread_end&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッドフッター(1000.txt)編集</a><br />
</div>

<h1>スレッドフッター(1000.txt)編集</h1>

<?cs if:Code0 ?>
<?cs if:Done_meta_save_thread_end ?><div class="noticeSuccess" id="notify"><p>スレッドフッター(1000.txt)を更新しました</p></div>
<?cs else ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>時刻欄の形式が正しくありません</p></div><?cs /if ?>
<?cs /if ?>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/respreview.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
var formArea;
jQuery(function(){
new Zeromin2.ResPreview({
    "content":     "<div class='footer' id='preview'></div>",
    "date":        "<?cs var:html_escape(item.date) ?>",
    "formID":      "metaThreadFooterContainerForm",
    "isTypeTheme": <?cs if:IsTypeTheme ?>true<?cs else ?>false<?cs /if ?>,
    "staticURI":   "<?cs var:html_escape(StaticURI) ?>",
    "text":        "<?cs var:text ?>",
    "typeTheme":   "<?cs var:html_escape(BBS_TYPE_THEME) ?>" });
});
//]]>
</script>

<p>
スレッドフッター(1000.txt)を編集します。<br />
プレビューを表示させるにはiframeとJavaScriptを有効にする必要があります。
</p>

<p>
<div id="previewFrame" class="hide"><iframe></iframe></div>
<input type="submit" value="1000.txtの更新を行う" /><br />
<label for="FROM" title="FROM">名前欄</label>
<input type="text" size="40" id="FROM" name="FROM" title="FROM" value="<?cs var:html_escape(Name) ?>" /><br />
<label for="mail">メール欄</label>
<input type="text" size="40" id="mail" name="mail" title="mail" value="<?cs var:html_escape(Mail) ?>" /><br />
<label for="date">時刻</label>
<input type="text" size="40" id="date" name="date" title="title" value="<?cs var:html_escape(Date) ?>" /><br />
<textarea name="MESSAGE" cols="50" rows="10">
<?cs var:html_escape(Message) ?>
</textarea><br />
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="meta" />
<input type="hidden" name="method" value="save_thread_end" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_thread_end" />
<input type="hidden" name="NG" value="load_thread_end" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
